import logging

## Virtual hosts configuration
hosts = {
        'biblio.local:8000': [
            {
                'path': r'/',
                'target': 'http://biblio.vincennes.fr',
                'mapping': 'mandaye_vincennes.configs.biblio_vincennes.biblio_mapping',
                },
            ],
        'espace-famille.local:8000': [
            {
                'path': r'/',
                'target': 'https://vincennes-noredirect.espace-famille.net',
                'mapping': 'mandaye_vincennes.configs.famille_vincennes.famille_mapping',
                }
            ],

        'conservatoire.local:8000': [
            {
                'path': r'/',
                'target': 'https://extranet.duonet.fr',
                'mapping': 'mandaye_vincennes.configs.duonet_vincennes.duonet_mapping',
                }
            ],
        }

## SQL Backend config
# http://docs.sqlalchemy.org/en/rel_0_7/core/engines.html
# rfc 1738 https://tools.ietf.org/html/rfc1738
# dialect+driver://username:password@host:port/database
db_url = 'postgresql://@localhost:5432/mandaye_vincennes'

## Logging configuration
debug = False
log_file = '/var/log/mandaye-vincennes/mandaye.log'
log_level = logging.INFO

## PATH
# Static url
static_url = '/static'
# Static folder
static_root = '/usr/share/mandaye-vincennes/static'
# Data directory
data_dir = '/var/lib/mandaye-vincennes/data'

## Email notification configuration
email_notification = True
smtp_host = 'localhost'
smtp_port = 25
email_from = 'admin+mandaye-vincennes@entrouvert.com'
email_to = ['admin+mandaye-vincennes@entrouvert.com']


## Session configuration
# http://beaker.readthedocs.org/en/latest/configuration.html#options-for-sessions-and-caching
session_opts = {
        'session.type': 'file',
        'session.cookie_expires': True,
        'session.timeout': 3600,
        'session.data_dir': '/var/lib/mandaye-vincennes/sessions'
}

## Encrypt service provider passwords with a secret
# You should install pycypto to use this feature
encrypt_sp_password = True
# Must be a 16, 24, or 32 bytes long
encrypt_secret = 'CHANGEME'

